@@ -7,7 +7,8 @@ import torch
 import numpy as np
 
 from .models.experimental import attempt_load
-from .utils.general import non_max_suppression
+from .utils.general import non_max_suppression, non_max_suppression_kpt
+from .utils.torch_utils import TracedModel
 
 
 def conf2color(conf):
@@ -17,6 +18,89 @@ def conf2color(conf):
         color = colorsys.hsv_to_rgb((25 + 100 * (2 * conf - 1.2)) / 360.0, 1, 1)
     return [k * 255 for k in reversed(color)]
 
+coco_names = ["person",
+              "bicycle",
+              "car",
+              "motorbike",
+              "aeroplane",
+              "bus",
+              "train",
+              "truck",
+              "boat",
+              "traffic light",
+              "fire hydrant",
+              "stop sign",
+              "parking meter",
+              "bench",
+              "bird",
+              "cat",
+              "dog",
+              "horse",
+              "sheep",
+              "cow",
+              "elephant",
+              "bear",
+              "zebra",
+              "giraffe",
+              "backpack",
+              "umbrella",
+              "handbag",
+              "tie",
+              "suitcase",
+              "frisbee",
+              "skis",
+              "snowboard",
+              "sports ball",
+              "kite",
+              "baseball bat",
+              "baseball glove",
+              "skateboard",
+              "surfboard",
+              "tennis racket",
+              "bottle",
+              "wine glass",
+              "cup",
+              "fork",
+              "knife",
+              "spoon",
+              "bowl",
+              "banana",
+              "apple",
+              "sandwich",
+              "orange",
+              "broccoli",
+              "carrot",
+              "hot dog",
+              "pizza",
+              "donut",
+              "cake",
+              "chair",
+              "sofa",
+              "pottedplant",
+              "bed",
+              "diningtable",
+              "toilet",
+              "tvmonitor",
+              "laptop",
+              "mouse",
+              "remote",
+              "keyboard",
+              "cell phone",
+              "microwave",
+              "oven",
+              "toaster",
+              "sink",
+              "refrigerator",
+              "book",
+              "clock",
+              "vase",
+              "scissors",
+              "teddy bear",
+              "hair drier",
+              "toothbrush"]
+
+
+
 class Yolov7Detector:
     def __init__(self,
                  weights=None,
@@ -25,7 +109,8 @@ class Yolov7Detector:
                  iou_thres=0.45,
                  augment=False,
                  agnostic_nms=False,
-                 device='cuda:0'):
+                 device='cuda:0',
+                 traced=False):
         if img_size is None:
             img_size = [640, 640]
         if weights is None:
@@ -43,15 +128,24 @@ class Yolov7Detector:
         self.half = self.device.type != 'cpu'
 
         sys.path.append(os.path.join(os.path.dirname(__file__), ""))
+        load_err = False
+
+        if not traced:
+            self.model = attempt_load(weights, map_location=self.device)  # load FP32 model
+        else:
+            self.model = torch.jit.load(weights[0], map_location=self.device).float().eval()
+
+        self.traced = traced
 
-        self.model = attempt_load(weights, map_location=self.device)  # load FP32 model
-        self.stride = int(self.model.stride.max())  # model stride
         self.img_size = img_size  # check_img_size(img_size, s=self.stride)  # check img_size
 
+
+        #self.stride = int(self.model.stride.max())  # model stride
+
         if self.half:
             self.model.half()
 
-        self.names = self.model.module.names if hasattr(self.model, 'module') else self.model.names
+        self.names = coco_names
         self.model.eval()
 
     def detect(self, x) -> (list, list, list):
@@ -69,22 +163,30 @@ class Yolov7Detector:
             boxes = []
             confs = []
             img_sizes = []
+            y = []
             for i, img in enumerate(x):
                 img_sizes.append(img.shape)
                 img_inf = cv2.resize(img, self.img_size)
                 # img_inf = letterbox(img, self.img_size, stride=self.stride)[0]
-                img_inf = img_inf[:, :, ::-1].transpose(2, 0, 1)  # BGR to RGB, to 3x416x416
+                img_inf = img_inf[:, :, ::-1].transpose(2, 0, 1)
                 img_inf = np.ascontiguousarray(img_inf)
 
                 img_inf = torch.from_numpy(img_inf).to(self.device)
                 img_inf = img_inf.half() if self.half else img_inf.float()  # uint8 to fp16/32
                 img_inf /= 255.0  # 0 - 255 to 0.0 - 1.0
-                x[i] = img_inf
+                y.append(img_inf)
+
+            y = torch.stack(y)
+            pred = self.model(y, )[0] # augment=self.augment
+            #print(pred.shape)
+            #if self.traced:
+            #    pred = pred[0].unsqueeze(0)
+
+            #print(pred.shape)
 
-            x = torch.stack(x)
-            pred = self.model(x, augment=self.augment)[0]
             pred = non_max_suppression(pred, self.conf_thres, self.iou_thres, classes=None,
                                        agnostic=self.agnostic_nms)
+            #print(pred)
             for i, det in enumerate(pred):  # detections per image
                 local_classes = []
                 local_boxes = []
@@ -92,7 +194,7 @@ class Yolov7Detector:
                 old_shape = img_sizes[i]
                 #gn = torch.tensor(old_shape)[[1, 0, 1, 0]]  # normalization gain whwh
                 if len(det):
-                    dx =  old_shape[0] / self.img_size[0]
+                    dx = old_shape[0] / self.img_size[0]
                     dy = old_shape[1] / self.img_size[1]
                     #print(det[:, :4])
                     #det[:, :4] = scale_coords(self.img_size, det[:, :4], old_shape[:2]).round()
